Method: Reviewer::Command::String#flags

Defined in:
lib/reviewer/command/string.rb

#flagsString

Gets the flags to be used in conjunction with the review command for a tool

1. The `review` commands are the only commands that use flags
2. If no flags are configured, this won't do anything

Returns:

  • (String)

    the concatenated list of flags to pass to the review command



64
65
66
67
68
# File 'lib/reviewer/command/string.rb', line 64

def flags
  return nil unless flags?

  Flags.new(tool_settings.flags).to_s
end