Class: Reviewer::Doctor::EnvironmentCheck
- Inherits:
-
Object
- Object
- Reviewer::Doctor::EnvironmentCheck
- Defined in:
- lib/reviewer/doctor/environment_check.rb
Overview
Checks environment prerequisites (git, Ruby version)
Instance Attribute Summary collapse
-
#report ⇒ Object
readonly
Returns the value of attribute report.
Instance Method Summary collapse
-
#check ⇒ Object
Checks Ruby version and git availability.
-
#initialize(report) ⇒ EnvironmentCheck
constructor
Creates an environment checker for Ruby and git availability.
Constructor Details
#initialize(report) ⇒ EnvironmentCheck
Creates an environment checker for Ruby and git availability
15 16 17 |
# File 'lib/reviewer/doctor/environment_check.rb', line 15 def initialize(report) @report = report end |
Instance Attribute Details
#report ⇒ Object (readonly)
Returns the value of attribute report.
9 10 11 |
# File 'lib/reviewer/doctor/environment_check.rb', line 9 def report @report end |
Instance Method Details
#check ⇒ Object
Checks Ruby version and git availability
20 21 22 23 |
# File 'lib/reviewer/doctor/environment_check.rb', line 20 def check check_ruby_version check_git end |