Module: Reviewer
- Defined in:
- lib/reviewer.rb,
lib/reviewer/tool.rb,
lib/reviewer/batch.rb,
lib/reviewer/setup.rb,
lib/reviewer/shell.rb,
lib/reviewer/tools.rb,
lib/reviewer/doctor.rb,
lib/reviewer/output.rb,
lib/reviewer/prompt.rb,
lib/reviewer/report.rb,
lib/reviewer/runner.rb,
lib/reviewer/command.rb,
lib/reviewer/context.rb,
lib/reviewer/history.rb,
lib/reviewer/session.rb,
lib/reviewer/version.rb,
lib/reviewer/arguments.rb,
lib/reviewer/shell/timer.rb,
lib/reviewer/tool/timing.rb,
lib/reviewer/capabilities.rb,
lib/reviewer/shell/result.rb,
lib/reviewer/configuration.rb,
lib/reviewer/doctor/report.rb,
lib/reviewer/runner/result.rb,
lib/reviewer/setup/catalog.rb,
lib/reviewer/tool/settings.rb,
lib/reviewer/arguments/tags.rb,
lib/reviewer/command/string.rb,
lib/reviewer/output/printer.rb,
lib/reviewer/setup/detector.rb,
lib/reviewer/arguments/files.rb,
lib/reviewer/batch/formatter.rb,
lib/reviewer/runner/guidance.rb,
lib/reviewer/setup/formatter.rb,
lib/reviewer/setup/generator.rb,
lib/reviewer/doctor/formatter.rb,
lib/reviewer/report/formatter.rb,
lib/reviewer/runner/formatter.rb,
lib/reviewer/setup/tool_block.rb,
lib/reviewer/tool/conversions.rb,
lib/reviewer/output/formatting.rb,
lib/reviewer/session/formatter.rb,
lib/reviewer/arguments/keywords.rb,
lib/reviewer/command/string/env.rb,
lib/reviewer/setup/gemfile_lock.rb,
lib/reviewer/tool/file_resolver.rb,
lib/reviewer/doctor/config_check.rb,
lib/reviewer/runner/failed_files.rb,
lib/reviewer/command/string/flags.rb,
lib/reviewer/configuration/loader.rb,
lib/reviewer/doctor/keyword_check.rb,
lib/reviewer/doctor/tool_inventory.rb,
lib/reviewer/tool/test_file_mapper.rb,
lib/reviewer/doctor/environment_check.rb,
lib/reviewer/doctor/opportunity_check.rb,
lib/reviewer/runner/strategies/captured.rb,
lib/reviewer/runner/strategies/passthrough.rb
Overview
Primary interface for the reviewer tools
Defined Under Namespace
Modules: Doctor, Setup Classes: Arguments, Batch, Capabilities, Command, Configuration, Context, Error, History, Output, Prompt, Report, Runner, Session, Shell, Tool, Tools
Constant Summary collapse
- VERSION =
'1.0.0'
Class Method Summary collapse
-
.arguments ⇒ Reviewer::Arguments
The collection of arguments that were passed via the command line.
-
.configuration ⇒ Reviewer::Configuration
Exposes the configuration options for Reviewer.
-
.configure {|configuration| ... } ⇒ Reviewer::Configuration
A block approach to configuring Reviewer.
-
.format ⇒ void
Runs the
formatcommand for the specified tools/files for which it is configured. -
.history ⇒ Reviewer::History
A file store for sharing information across runs.
-
.output ⇒ Reviewer::Output
The primary output method for Reviewer to consistently display success/failure details for a unique run of each tool and the collective summary when relevant.
-
.prompt ⇒ Reviewer::Prompt
An interactive prompt for yes/no questions.
-
.reset! ⇒ Object
Resets the loaded tools and arguments.
-
.review ⇒ void
Runs the
reviewcommand for the specified tools/files. -
.tools ⇒ Reviewer::Tools
An interface for the collection of configured tools for accessing subsets of tools based on enabled/disabled, tags, keywords, etc.
Class Method Details
.arguments ⇒ Reviewer::Arguments
The collection of arguments that were passed via the command line.
56 |
# File 'lib/reviewer.rb', line 56 def arguments = @arguments ||= Arguments.new |
.configuration ⇒ Reviewer::Configuration
Exposes the configuration options for Reviewer.
83 |
# File 'lib/reviewer.rb', line 83 def configuration = @configuration ||= Configuration.new |
.configure {|configuration| ... } ⇒ Reviewer::Configuration
A block approach to configuring Reviewer.
93 |
# File 'lib/reviewer.rb', line 93 def configure = yield(configuration) |
.format ⇒ void
This method returns an undefined value.
Runs the format command for the specified tools/files for which it is configured.
49 50 51 |
# File 'lib/reviewer.rb', line 49 def format handle_early_exits { exit build_session.format } end |
.history ⇒ Reviewer::History
A file store for sharing information across runs
73 |
# File 'lib/reviewer.rb', line 73 def history = @history ||= History.new(file: configuration.history_file) |
.output ⇒ Reviewer::Output
The primary output method for Reviewer to consistently display success/failure details for a
unique run of each tool and the collective summary when relevant.
68 |
# File 'lib/reviewer.rb', line 68 def output = @output ||= Output.new |
.prompt ⇒ Reviewer::Prompt
An interactive prompt for yes/no questions
78 |
# File 'lib/reviewer.rb', line 78 def prompt = @prompt ||= Prompt.new |
.reset! ⇒ Object
Resets the loaded tools and arguments
36 |
# File 'lib/reviewer.rb', line 36 def reset! = @tools = @arguments = @prompt = @output = @history = @configuration = nil |
.review ⇒ void
This method returns an undefined value.
Runs the review command for the specified tools/files. Reviewer expects all configured
commands that are not disabled to have an entry for the `review` command.
42 43 44 |
# File 'lib/reviewer.rb', line 42 def review handle_early_exits { exit build_session.review } end |
.tools ⇒ Reviewer::Tools
An interface for the collection of configured tools for accessing subsets of tools
based on enabled/disabled, , keywords, etc.
62 |
# File 'lib/reviewer.rb', line 62 def tools = @tools ||= Tools.new(arguments: arguments, history: history, config_file: configuration.file) |