Module: Reviewer::Doctor

Defined in:
lib/reviewer/doctor.rb,
lib/reviewer/doctor/report.rb,
lib/reviewer/doctor/formatter.rb,
lib/reviewer/doctor/config_check.rb,
lib/reviewer/doctor/keyword_check.rb,
lib/reviewer/doctor/tool_inventory.rb,
lib/reviewer/doctor/environment_check.rb,
lib/reviewer/doctor/opportunity_check.rb

Overview

Diagnostic module for checking configuration, tools, and environment health

Defined Under Namespace

Classes: ConfigCheck, EnvironmentCheck, Formatter, KeywordCheck, OpportunityCheck, Report, ToolInventory

Class Method Summary collapse

Class Method Details

.run(configuration:, tools:, project_dir: Pathname.pwd) ⇒ Doctor::Report

Runs all diagnostic checks and returns a structured report

Parameters:

  • project_dir (Pathname) (defaults to: Pathname.pwd)

    the project root to scan

Returns:



18
19
20
21
22
23
24
25
26
# File 'lib/reviewer/doctor.rb', line 18

def self.run(configuration:, tools:, project_dir: Pathname.pwd)
  report = Report.new
  ConfigCheck.new(report, configuration: configuration).check
  KeywordCheck.new(report, configuration: configuration, tools: tools).check
  ToolInventory.new(report, configuration: configuration, tools: tools).check
  OpportunityCheck.new(report, project_dir, configuration: configuration, tools: tools).check
  EnvironmentCheck.new(report).check
  report
end